diff --git a/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c b/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c
index 08419a9660cd41b2eb8d41528302fc388c150830..a56471568bfaeb534cdce3e3944906252c4de048 100644
--- a/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c
+++ b/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c
@@ -106,7 +106,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.InterfaceNumber        = 0x00,
 			.AlternateSetting       = 0x00,
 			
-			.TotalEndpoints         = 2,
+			.TotalEndpoints         = 3,
 				
 			.Class                  = 0xFE,
 			.SubClass               = 0x03,
@@ -133,6 +133,16 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Attributes             = (EP_TYPE_BULK | ENDPOINT_ATTR_NO_SYNC | ENDPOINT_USAGE_DATA),
 			.EndpointSize           = TMC_IO_EPSIZE,
 			.PollingIntervalMS      = 0x00
+		},
+		
+	.NotificationEndpoint = 
+		{
+			.Header                 = {.Size = sizeof(USB_Descriptor_Endpoint_t), .Type = DTYPE_Endpoint},
+			
+			.EndpointAddress        = (ENDPOINT_DESCRIPTOR_DIR_IN | TMC_NOTIFICATION_EPNUM),
+			.Attributes             = (EP_TYPE_INTERRUPT | ENDPOINT_ATTR_NO_SYNC | ENDPOINT_USAGE_DATA),
+			.EndpointSize           = TMC_NOTIFICATION_EPSIZE,
+			.PollingIntervalMS      = 0xFF
 		}
 };
 
diff --git a/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.h b/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.h
index d0f17b1e9156653a1e41e4e437b5c12396eec126..468a5ea1d2cc469b00516a8f21cb687ce2fc55c9 100644
--- a/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.h
+++ b/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.h
@@ -44,13 +44,19 @@
 
 	/* Macros: */
 		/** Endpoint number of the TMC device-to-host data IN endpoint. */
-		#define TMC_IN_EPNUM          3	
+		#define TMC_IN_EPNUM            3	
 
 		/** Endpoint number of the TMC host-to-device data OUT endpoint. */
-		#define TMC_OUT_EPNUM         4	
+		#define TMC_OUT_EPNUM           4	
+
+		/** Endpoint number of the TMC notification IN endpoint. */
+		#define TMC_NOTIFICATION_EPNUM  2	
 
 		/** Size in bytes of the TMC data endpoints. */
-		#define TMC_IO_EPSIZE         64
+		#define TMC_IO_EPSIZE           64
+
+		/** Size in bytes of the TMC notification endpoint. */
+		#define TMC_NOTIFICATION_EPSIZE 8
 
 	/* Type Defines: */
 		/** Type define for the device configuration descriptor structure. This must be defined in the
@@ -63,6 +69,7 @@
 			USB_Descriptor_Interface_t            Interface;
 			USB_Descriptor_Endpoint_t             DataOutEndpoint;
 			USB_Descriptor_Endpoint_t             DataInEndpoint;
+			USB_Descriptor_Endpoint_t             NotificationEndpoint;
 		} USB_Descriptor_Configuration_t;
 
 	/* Function Prototypes: */
diff --git a/LUFA/ManPages/ChangeLog.txt b/LUFA/ManPages/ChangeLog.txt
index 6ea4dfb7606e87a2904dd35c080489b2ec28e253..e76b3448a1d349cbd8649c950fd6c7576af247eb 100644
--- a/LUFA/ManPages/ChangeLog.txt
+++ b/LUFA/ManPages/ChangeLog.txt
@@ -5,6 +5,9 @@
  */
 
  /** \page Page_ChangeLog Project Changelog
+  *
+  *  \section Sec_ChangeLogXXXXXX Version XXXXXX
+  *  There is currently no changelog information for this release.
   *
   *  \section Sec_ChangeLog100807 Version 100807
   *  <b>New:</b>
diff --git a/LUFA/ManPages/MigrationInformation.txt b/LUFA/ManPages/MigrationInformation.txt
index f620020d71417c3aaecbab0993c808e320e79b41..8251423924b2ea4bc9e060cf4701c5d54a3702c4 100644
--- a/LUFA/ManPages/MigrationInformation.txt
+++ b/LUFA/ManPages/MigrationInformation.txt
@@ -10,6 +10,9 @@
  *  to the next version released. It does not indicate all new additions to the library in each version change, only
  *  areas relevant to making older projects compatible with the API changes of each new release.
  *
+ * \section Sec_MigrationXXXXXX Migrating from XXXXXX to XXXXXX
+ * There is currently no migration information for this release.
+ *
  * \section Sec_Migration100807 Migrating from 100513 to 100807
  *
  *  <b>Non-USB Library Components</b>
diff --git a/LUFA/Version.h b/LUFA/Version.h
index ed8af11f473c58946302c8e0ca8c93b8e9b418f0..986ad1e7ff96240be57231d4c4fe784c0bc889ad 100644
--- a/LUFA/Version.h
+++ b/LUFA/Version.h
@@ -43,9 +43,9 @@
 	/* Public Interface - May be used in end-application: */
 		/* Macros: */
 			/** Indicates the version number of the library, as an integer. */
-			#define LUFA_VERSION_INTEGER     0x100807
+			#define LUFA_VERSION_INTEGER     0x000000
 
 			/** Indicates the version number of the library, as a string. */
-			#define LUFA_VERSION_STRING      "100807"
+			#define LUFA_VERSION_STRING      "XXXXXX"
 
 #endif
diff --git a/Demos/Device/Incomplete/TestAndMeasurement/TestAndMeasurement.c b/Demos/Device/Incomplete/TestAndMeasurement/TestAndMeasurement.c
index 040cb345d8e87d77d38d49579355444495ce3368..e174aa99837ee6460045bf1d6983c352fa55f853 100644
--- a/Demos/Device/Incomplete/TestAndMeasurement/TestAndMeasurement.c
+++ b/Demos/Device/Incomplete/TestAndMeasurement/TestAndMeasurement.c
@@ -120,7 +120,7 @@ void EVENT_USB_Device_ConfigurationChanged(void)
 {
 	LEDs_SetAllLEDs(LEDMASK_USB_READY);
 
 	/* Setup TMC In and Out Endpoints */
 	if (!(Endpoint_ConfigureEndpoint(TMC_IN_EPNUM, EP_TYPE_BULK,
 		                             ENDPOINT_DIR_IN, TMC_IO_EPSIZE,
 	                                 ENDPOINT_BANK_SINGLE)))
@@ -134,6 +134,13 @@ void EVENT_USB_Device_ConfigurationChanged(void)
 	{
 		LEDs_SetAllLEDs(LEDMASK_USB_ERROR);
 	}
+
+	if (!(Endpoint_ConfigureEndpoint(TMC_NOTIFICATION_EPNUM, EP_TYPE_INTERRUPT,
+		                             ENDPOINT_DIR_IN, TMC_NOTIFICATION_EPSIZE,
+	                                 ENDPOINT_BANK_SINGLE)))
+	{
+		LEDs_SetAllLEDs(LEDMASK_USB_ERROR);
+	}
 }
 
 /** Event handler for the USB_UnhandledControlRequest event. This is used to catch standard and class specific
@@ -120,7 +120,7 @@ void EVENT_USB_Device_ConfigurationChanged(void)
 	LEDs_SetAllLEDs(LEDMASK_USB_READY);
 
-	/* Setup TMC In and Out Endpoints */
+	/* Setup TMC In, Out and Notification Endpoints */
 	if (!(Endpoint_ConfigureEndpoint(TMC_IN_EPNUM, EP_TYPE_BULK,
 		                             ENDPOINT_DIR_IN, TMC_IO_EPSIZE,